Atlassian-Transfer
==============

An API wrapper for Atlassian's https://transfer.atlassian.com file upload site.

Installation
------------

Atlassian-Transfer is available on PyPI and can be installed with:

    pip install atlassian-transfer


Quick start
-----------
